@@ -7,7 +7,7 @@ import threading
 
 import requests
 
-__version__ = '1.5.1b'
+__version__ = '1.5.2b'
 
 class Event(object):
 	def __init__(self, connection):
@@ -140,16 +140,10 @@ class Client(object):
 		self.__login(username, password)
 		data = self.__wikia_request(controller="Chat", format="json")
 		self.settings = {}
-		if key:
-			self.settings["chatkey"] = key
-		else:
-			self.settings['chatkey'] = data['chatkey']
+		self.settings['chatkey'] = data['chatkey']
 		self.settings["port"] = data["nodePort"]
 		self.settings["host"] = data["nodeHostname"]
-		if priv:
-			self.settings["room"] = self.__private_message_id(priv)
-		else:
-			self.settings["room"] = data["roomId"]
+		self.settings["room"] = data["roomId"]
 		self.settings["chatmod"] = data["isChatMod"]
 		self.settings["session"] = self.__get_session(self.settings)
 		self.xhr = self.__initialize(self.settings)
